/*!
\file boundry.cpp
\brief Class definition for Boundry
\author Nicholas Phillips, phillips@friday.gsfc.nasa.gov
\date Feb 23, 2004
*/
#include <iostream>
#include <math.h>
#include "boundry.h"

using namespace std;
//=====================================================================================
void Boundry::set_eq(const double z, const double phi, const int direction)
{
	b = direction*0.375*M_PI;
	a = phi - b*z;
 	eq = true;
	return;
}
//=====================================================================================
void Boundry::set_np(const double z, const double phi, const int face_)
{
 	eq = false;
	face = face_;
	a = sqrt(1-z)*(0.5*M_PI*(face+1) - phi);
	return;
}
//=====================================================================================
void Boundry::set_sp(const double z, const double phi, const int face_)
{
 	eq = false;
	face = face_;
	a = sqrt(1+z)*(phi - 0.5*M_PI*(face-8));
	return;
}
//=====================================================================================
double Boundry::operator()(const double z) const
{
	double phi;
	if( eq )
		phi = a + b*z;
	else if( face < 4) {
		phi = 0.5*M_PI*(face+1);
		if( z < 1 )
			phi += -a/sqrt(1-z);
	}
	else if( face > 7) {
		phi = 0.5*M_PI*(face-8);
		if( z > -1 )
			phi += a/sqrt(1+z);
	}
	else {
		cerr << "Boundry::operator():Bad call" << endl;
		phi = 0;
	}
	return phi;
}

