/*!
\file selector.h
\brief Class declaration for Selector
\author Nicholas Phillips, phillips@friday.gsfc.nasa.gov
\date Sep 24, 2004
*/
#ifndef SELECTOR_H
#define SELECTOR_H

#include <QGLViewer/camera.h>
#include <QGLViewer/vec.h>
#include "projection.h"

/**
@author Nicholas Phillips
*/
class Selector{
public:
    Selector();
    virtual ~Selector();

	//! Given cursor position, which point on the sphere, if any
	bool select(const QPoint& point, qglviewer::Camera *camera, Projection *projection);
	//! If there is a current selected, determine healpix number
	long toHealpix(const Skymap & skymap);
	//! Return pixnum from last call to toHealpix()
	long selectedPixel() const { return current_pix; }
	//! Include in the current OpenGL context
	void draw();
	//! Animate the throb sphere color
	void animate();
	//! Clear all selections
	void clear();
private:
	void drawSphere();
private:
	bool selected;		//!< \c true when there an active selected point
	qglviewer::Vec v;	//!< 3D point of selected
	long current_pix;	//!< Current selected pixel

	float dc;			//!< color increment/decrement amount
	float lower_lim;	//!< lower limit of current
	float direction;	//!< increment or decrement?
	float color;		//!< current color value

};

#endif
